@@ -1002,6 +1002,7 @@ class Base_Page(Borg, unittest.TestCase):
 
 
 
+
     def hover(self, locator, wait_seconds=0.5):
         "Hover over the element"
         # Note: perform() of ActionChains does not return a bool
@@ -1228,4 +1229,13 @@ class Base_Page(Borg, unittest.TestCase):
     def set_maximize_window(self):
         self.driver.maximize_window()
 
+    def scroll_by_amount(self, locator, delta_x: int, delta_y: int):
+        try:
+            element = self.get_element(locator)
+            element.scroll_by_amount(delta_x, delta_y)
+        except Exception as e:
+            self.write(str(e), 'debug')
+            self.exceptions.append("An exception occured when scroll by amount")
+            return None
+
     # _get_locator = staticmethod(_get_locator) "COMMENT BECAUSE _get_locator commented"
